api.customers.v1 package — Argus-Toolbelt 1.0 documentation

# api.customers.v1 package

## Submodules

## api.customers.v1.customer module

Autogenerated API

`api.customers.v1.customer.` `add_customer`(name: str = None, shortName: str = None, properties: dict = None, logoURL: str = None, accountManagerID: int = None, features: list = None, language: str = 'ENGLISH', timeZone: str = 'Europe/Oslo', type: str = 'CUSTOMER', parentID: int = 0, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Create a new customer (PUBLIC)

  Return type: | `dict`
  Parameters: | name (str) – Name to set for new customer. => [sw{}$-().[]“‘_/,*+#:@!?;]* shortName (str) – shortName to set for new customer (must be unique). => [a-zA-Z0-9_-.]* properties (dict) – Properties to set for customer. => [sw{}$-().[]“‘_/,*+#:@!?;]* logoURL (str) – Customer logo data url. On format data:image/jpeg;base64,BASE64STRING. => Sanitize by regex data:.* accountManagerID (int) – ID of account manager to assign to customer. If not set, no account manager is set. features (list) – Features to enable on customer. language (str) – Language to set for customer. (default ENGLISH) timeZone (str) – Name of timezone to set for customer. (default Europe/Oslo) type (str) – Object type. If set to GROUP, this customer can have subcustomers. (default CUSTOMER) parentID (int) – ID of parent customer group to add this customer to. (default 0)
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 740, “limit”: 719, “responseCode”: 200, “count”: 588, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Early pay weight skin future story last.”, “messageTemplate”: “Matter expert whether foot indicate her.”, “field”: “Focus defense find base son name of.”, “parameter”: {}, “timestamp”: 384602930}], “currentPage”: 640, “size”: 696}

`api.customers.v1.customer.` `add_customer_service`(customerID: int, service: str = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Add a service to a customer. (PUBLIC)

  Return type: | `dict`
  Parameters: | customerID (int) – Customer ID service (str) – Name of service to enable on customer
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 463, “limit”: 997, “responseCode”: 200, “count”: 599, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Tv reach know most.”, “messageTemplate”: “Nothing share standard town.”, “field”: “Age ever case parent attack stand apply.”, “parameter”: {}, “timestamp”: 134136427}], “currentPage”: 946, “size”: 764}

`api.customers.v1.customer.` `disable_customer`(id: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Disable customer. (PUBLIC)

  Return type: | `dict`
  Parameters: | id (int) – Customer ID
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 387, “limit”: 791, “responseCode”: 200, “count”: 609, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Rich director animal.”, “messageTemplate”: “This between continue with decision operation.”, “field”: “Music this pretty let.”, “parameter”: {}, “timestamp”: 1386429872}], “currentPage”: 260, “size”: 551}

`api.customers.v1.customer.` `get_customer_by_id`(id: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Returns a Customer identified by its ID. (PUBLIC)

  Return type: | `dict`
  Parameters: | id (int) – Customer ID
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 329, “limit”: 943, “responseCode”: 200, “count”: 251, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Politics similar inside dark.”, “messageTemplate”: “Alone blue help fact usually.”, “field”: “Project lead ask together tax general.”, “parameter”: {}, “timestamp”: 1441469954}], “currentPage”: 500, “size”: 733}

`api.customers.v1.customer.` `get_customer_by_shortname`(shortName: str, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Returns a Customer identified by its shortname. (PUBLIC)

  Return type: | `dict`
  Parameters: | shortName (str) – Customer shortname
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 189, “limit”: 678, “responseCode”: 200, “count”: 475, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Its several peace including.”, “messageTemplate”: “Appear successful my family as argue want.”, “field”: “Model learn current six.”, “parameter”: {}, “timestamp”: 1108116474}], “currentPage”: 671, “size”: 621}

`api.customers.v1.customer.` `get_customer_logo_by_id`(id: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Returns a Customer logo by customer shortname. (PUBLIC)

  Return type: | `dict`
  Parameters: | id (int) – Customer ID
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {}

`api.customers.v1.customer.` `get_customer_logo_by_shortname`(shortName: str, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Returns a Customer logo by customer shortname. (PUBLIC)

  Return type: | `dict`
  Parameters: | shortName (str) – Customer shortname
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {}

`api.customers.v1.customer.` `list_customers`(parentID: list = None, service: list = None, keywords: list = None, keywordField: list = None, sortBy: list = None, offset: int = 0, limit: int = 25, keywordMatch: str = 'all', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Returns customers defined by query parameters (PUBLIC)

  Return type: | `dict`
  Parameters: | parentID (list) – Search by parentID service (list) – Search by services keywords (list) – Search by keywords keywordField (list) – Set field strategy for keyword search sortBy (list) – Sort search result offset (int) – Skip a number of results limit (int) – Maximum number of returned results keywordMatch (str) – Set match strategy for keyword search
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 780, “limit”: 329, “responseCode”: 200, “count”: 29, “data”: [{“id”: 764, “flags”: [“INITIAL_TUNING”], “name”: “Kimberly Schultz”, “shortName”: “Station win individual dream himself trip.”, “properties”: {“additionalProperties”: “Music physical magazine yes summer which.”}, “services”: [{“id”: 41, “name”: “Adrian Thompson”, “description”: “Break yet feeling TV piece throw.”}], “createdByUser”: {“id”: 268, “customerID”: 515, “userName”: “walkerkimberly”, “name”: “Louis Weber”}, “createdTimestamp”: 13736734, “lastUpdatedByUser”: {“id”: 490, “customerID”: 578, “userName”: “stephaniewoods”, “name”: “Caroline Turner”}, “accountManager”: {“id”: 813, “customerID”: 234, “userName”: “ebarnes”, “name”: “Richard Gomez”}, “lastUpdatedTimestamp”: 290130034, “language”: “NORWEGIAN”}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “As deep usually goal.”, “messageTemplate”: “Wide house develop wish degree single set.”, “field”: “Mission TV give country.”, “parameter”: {}, “timestamp”: 694698937}], “currentPage”: 526, “size”: 982}

`api.customers.v1.customer.` `remove_customer_service`(customerID: int, service: str, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Remove a service from a customer. (PUBLIC)

  Return type: | `dict`
  Parameters: | customerID (int) – Customer ID service (str) – Name of service to remove
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 507, “limit”: 370, “responseCode”: 200, “count”: 524, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Knowledge reach girl everybody again recognize act.”, “messageTemplate”: “Line community relate base cost scene.”, “field”: “Assume whatever season eye catch trip population.”, “parameter”: {}, “timestamp”: 1201674967}], “currentPage”: 473, “size”: 982}

`api.customers.v1.customer.` `search_customers`(limit: int = None, offset: int = None, subCriteria: list = None, customerID: list = None, parentID: list = None, keywords: list = None, keywordMatchStrategy: str = None, keywordFieldStrategy: list = None, service: list = None, domain: list = None, sortBy: list = None, includeFlags: list = None, excludeFlags: list = None, includeDeleted: bool = 'False', exclude: bool = 'False', required: bool = 'False', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Returns customers defined by CustomerSearchCriteria (PUBLIC)

  Return type: | `dict`
  Parameters: | limit (int) – Set this value to set max number of results. By default, no restriction on result set size. offset (int) – Set this value to skip the first (offset) objects. By default, return result from first object. subCriteria (list) – customerID (list) – Restrict search to data belonging to specified customers. parentID (list) – Search for customers by parent customer ID. keywords (list) – Search for customers by keywords. keywordMatchStrategy (str) – Defines the MatchStrategy for keywords (default match all keywords). keywordFieldStrategy (list) – Defines which fields will be searched by keywords (default all supported fields). service (list) – Search for customers having any of these services (service shortname). domain (list) – Search for customers in one of these domains (by domain id or name). sortBy (list) – List of properties to sort by (prefix with “-” to sort descending). includeFlags (list) – Only include objects which have includeFlags set. excludeFlags (list) – Exclude objects which have excludeFlags set. includeDeleted (bool) – Set to true to include deleted objects. By default, exclude deleted objects. exclude (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria object will be excluded. required (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria are required (AND-ed together with parent criteria).
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 134, “limit”: 221, “responseCode”: 200, “count”: 70, “data”: [{“id”: 956, “flags”: [“ALLOW_API”], “name”: “Daniel Mccall”, “shortName”: “Sure popular thank already career its name participant.”, “properties”: {“additionalProperties”: “Yeah interesting nature exist.”}, “services”: [{“id”: 475, “name”: “Jacob Powell II”, “description”: “Believe should likely information.”}], “createdByUser”: {“id”: 673, “customerID”: 75, “userName”: “owalker”, “name”: “Christina Ho”}, “createdTimestamp”: 1384499907, “lastUpdatedByUser”: {“id”: 12, “customerID”: 658, “userName”: “andersoneric”, “name”: “Robert Armstrong”}, “accountManager”: {“id”: 394, “customerID”: 701, “userName”: “beth18”, “name”: “Jennifer Perry”}, “lastUpdatedTimestamp”: 912542602, “language”: “ENGLISH”}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “According performance national protect.”, “messageTemplate”: “According why during meet.”, “field”: “Sure author difficult.”, “parameter”: {}, “timestamp”: 1424562099}], “currentPage”: 708, “size”: 144}

`api.customers.v1.customer.` `update_customer`(id: int, name: str = None, shortName: str = None, language: str = None, addProperties: dict = None, deleteProperties: list = None, logoURL: str = None, timeZone: str = None, accountManagerID: int = None, addFeatures: list = None, deleteFeatures: list = None, type: str = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Update a customer object. (PUBLIC)

  Return type: | `dict`
  Parameters: | id (int) – Customer ID name (str) – If set, change customer name to this value. => [sw{}$-().[]“‘_/,*+#:@!?;]* shortName (str) – If set, change customer shortname to this value (must be unique). => [a-zA-Z0-9_-.]* language (str) – If set, change customer language. addProperties (dict) – If set, add these properties. If the keys exist, they will be overwritten. => [sw{}$-().[]“‘_/,*+#:@!?;]* deleteProperties (list) – If set, remove properties with these keys. Missing keys are ignored. logoURL (str) – If set, change customer logo. On format data:image/jpeg;base64,BASE64STRING. => Sanitize by regex data:.* timeZone (str) – If set, change customer timezone to timezone with this name. accountManagerID (int) – If set, change customer account manmager to specified user. addFeatures (list) – If set, add these features to customer. deleteFeatures (list) – If set, remove these features from customer. type (str) – Customer type. If set to GROUP, this customer can have subcustomers.
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 250, “limit”: 545, “responseCode”: 200, “count”: 705, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Rest car short present.”, “messageTemplate”: “No expert air tell wall.”, “field”: “Full cup tree.”, “parameter”: {}, “timestamp”: 427920083}], “currentPage”: 910, “size”: 165}

## Module contents